Catch2 Test Fixes (#2961)
* test fixes
* address PR comment
* PR comment fixing Nvidia pass
* add additional kernel launch checks
* pr comments
[ROCm/hip commit: c02b15fc7c]
This commit is contained in:
gecommit door
GitHub
bovenliggende
d133dafb5c
commit
8d371ed6b6
@@ -69,8 +69,8 @@ int main(){
|
||||
check("Registering A",status);
|
||||
cudaHostGetDevicePointer(&Ad, A, 0);
|
||||
cudaMalloc((void**)&Bd, SIZE);
|
||||
dim3 dimGrid(LEN/512,1,1);
|
||||
dim3 dimBlock(512,1,1);
|
||||
dim3 dimGrid(LEN/256,1,1);
|
||||
dim3 dimBlock(256,1,1);
|
||||
Inc1<<<dimGrid, dimBlock>>>(Ad, Bd);
|
||||
sleep(3);
|
||||
A[0] = -(ITER*1.0f);
|
||||
|
||||
@@ -71,8 +71,8 @@ int main() {
|
||||
B[i] = 2.0f;
|
||||
}
|
||||
|
||||
dim3 dimGrid(LEN / 512, 1, 1);
|
||||
dim3 dimBlock(512, 1, 1);
|
||||
dim3 dimGrid(LEN / 256, 1, 1);
|
||||
dim3 dimBlock(256, 1, 1);
|
||||
|
||||
hipLaunchKernelGGL(HIP_KERNEL_NAME(Add), dimGrid, dimBlock, 0, 0, Ad, Bd, Cd);
|
||||
|
||||
|
||||
@@ -134,8 +134,8 @@ int main() {
|
||||
HIPCHECK(hipMalloc((void**)&Bd, SIZE));
|
||||
HIPCHECK(hipMemcpy(Bd, B, SIZE, hipMemcpyHostToDevice));
|
||||
|
||||
dim3 dimGrid(LEN / 512, 1, 1);
|
||||
dim3 dimBlock(512, 1, 1);
|
||||
dim3 dimGrid(LEN / 256, 1, 1);
|
||||
dim3 dimBlock(256, 1, 1);
|
||||
|
||||
hipLaunchKernelGGL(Add, dimGrid, dimBlock, 0, 0, Ad, Bd, Cd);
|
||||
|
||||
|
||||
Verwijs in nieuw issue
Block a user